SQLAlchemy 0.3 Documentation - module sqlalchemy.databases.mysql

# SQLAlchemy 0.3 Documentation

Multiple Pages | One Page
Version: 0.3.7 Last Updated: 04/30/07 00:08:52

### module sqlalchemy.databases.mysql

### Module Functions

def descriptor()
def kw_colspec(self, spec)

### class MSBigInteger(MSInteger)

def get_col_spec(self)
back to section top

### class MSBinary(Binary)

def convert_result_value(self, value, dialect)
def get_col_spec(self)
back to section top

### class MSBoolean(Boolean)

def convert_bind_param(self, value, dialect)
def convert_result_value(self, value, dialect)
def get_col_spec(self)
back to section top

### class MSChar(CHAR)

def get_col_spec(self)
back to section top

### class MSDate(Date)

def get_col_spec(self)
back to section top

### class MSDateTime(DateTime)

def get_col_spec(self)
back to section top

### class MSDecimal(MSNumeric)

def get_col_spec(self)
back to section top

### class MSDouble(MSNumeric)

def __init__(self, precision=10, length=2, **kw)
def get_col_spec(self)
back to section top

### class MSEnum(MSString)

def __init__(self, *enums)
def get_col_spec(self)
back to section top

### class MSFloat(Float)

def __init__(self, precision=10, length=None, **kw)
def get_col_spec(self)
back to section top

### class MSInteger(Integer)

def __init__(self, length=None, **kw)
def get_col_spec(self)
back to section top

### class MSLongText(MSText)

def get_col_spec(self)
back to section top

### class MSMediumBlob(MSBinary)

def get_col_spec(self)
back to section top

### class MSMediumText(MSText)

def get_col_spec(self)
back to section top

### class MSNumeric(Numeric)

def __init__(self, precision=10, length=2, **kw)
def get_col_spec(self)
back to section top

### class MSSmallInteger(SmallInteger)

def __init__(self, length=None, **kw)
def get_col_spec(self)
back to section top

### class MSString(String)

def get_col_spec(self)
back to section top

### class MSText(TEXT)

def __init__(self, **kw)
def get_col_spec(self)
back to section top

### class MSTime(Time)

def convert_result_value(self, value, dialect)
def get_col_spec(self)
back to section top

### class MSTimeStamp(TIMESTAMP)

def get_col_spec(self)
back to section top

### class MSTinyText(MSText)

def get_col_spec(self)
back to section top

### class MySQLCompiler(ANSICompiler)

def for_update_clause(self, select)
def limit_clause(self, select)
def visit_cast(self, cast)

hey ho MySQL supports almost no types at all for CAST

back to section top

### class MySQLDialect(ANSIDialect)

def __init__(self, **kwargs)
def compiler(self, statement, bindparams, **kwargs)
def create_connect_args(self, url)
def create_execution_context(self, *args, **kwargs)
def dbapi(cls)
def do_execute(self, cursor, statement, parameters, **kwargs)
def do_executemany(self, cursor, statement, parameters, context=None, **kwargs)
def do_rollback(self, connection)
def get_default_schema_name(self)
def has_table(self, connection, table_name, schema=None)
def is_disconnect(self, e)
def moretableinfo(self, connection, table)

runs SHOW CREATE TABLE to get foreign key/options information about the table.

def preparer(self)
def reflecttable(self, connection, table)
def schemadropper(self, *args, **kwargs)
def schemagenerator(self, *args, **kwargs)
def supports_sane_rowcount(self)
def supports_unicode_statements(self)
def type_descriptor(self, typeobj)
back to section top

### class MySQLExecutionContext(DefaultExecutionContext)

def post_exec(self)
back to section top

### class MySQLIdentifierPreparer(ANSIIdentifierPreparer)

def __init__(self, dialect)
back to section top

### class MySQLSchemaDropper(ANSISchemaDropper)

def drop_foreignkey(self, constraint)
def visit_index(self, index)
back to section top

### class MySQLSchemaGenerator(ANSISchemaGenerator)

def get_column_specification(self, column, override_pk=False, first_pk=False)
def post_create_table(self, table)
back to section top

### class array(object)

array(typecode [, initializer]) -> array

Return a new array whose items are restricted by typecode, and initialized from the optional initializer value, which must be a list, string. or iterable over elements of the appropriate type.

Arrays represent basic values and behave very much like lists, except the type of objects stored in them is constrained.

Methods:

append() -- append a new item to the end of the array buffer_info() -- return information giving the current memory info byteswap() -- byteswap all the items of the array count() -- return number of occurences of an object extend() -- extend array by appending multiple elements from an iterable fromfile() -- read items from a file object fromlist() -- append items from the list fromstring() -- append items from the string index() -- return index of first occurence of an object insert() -- insert a new item into the array at a provided position pop() -- remove and return item (default last) read() -- DEPRECATED, use fromfile() remove() -- remove first occurence of an object reverse() -- reverse the order of the items in the array tofile() -- write all items to a file object tolist() -- return the array converted to an ordinary list tostring() -- return the array converted to a string write() -- DEPRECATED, use tofile()

Attributes:

typecode -- the typecode character used to create the array itemsize -- the length in bytes of one array item

itemsize = property()

the size, in bytes, of one array item

typecode = property()

the typecode character used to create the array

back to section top